CameraEffectTextures class

This model class represents the textures that are used by an Effect in the Camera.

Constructors

CameraEffectTextures({required String textureKey, required String? textureUrl})
Default constructor
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textureKey → String
The key of the texture.
final
textureUrl → String?
The texture url.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Method to map the data of a CameraEffectTextures object into a Map and use for channel method call.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited